@@ -1,6 +1,8 @@
 from __future__ import annotations
 from inspect import signature
 from typing import Any, Callable
+import warnings
+from PyQt5.QtWidgets import QVBoxLayout
 from qtpy.QtWidgets import QMenuBar, QWidget, QMainWindow, QBoxLayout
 from qtpy.QtCore import Qt
 from magicgui.widgets import Container, MainWindow,Label, FunctionGui, Image, Table
@@ -61,8 +63,16 @@ class ClassGuiBase(BaseGui):
                 
             if hasattr(widget, "value") and fld.record:
                 # By default, set value function will be connected to the widget.
-                f = value_widget_callback(self, widget, name, getvalue=type(fld) is MagicField)
+                getvalue = type(fld) is MagicField
+                f = value_widget_callback(self, widget, name, getvalue=getvalue)
                 widget.changed.connect(f)
+        
+        elif fld.callbacks:
+            msg = (
+                f"{type(widget).__name__} does not have value-change callback. "
+                f"Connecting callback functions does no effect."
+                )
+            warnings.warn(msg, UserWarning)
                 
         return widget
     
@@ -115,7 +125,7 @@ class ClassGuiBase(BaseGui):
                     widget.__magicclass_parent__ = self
                     self.__magicclass_children__.append(widget)
                     widget._my_symbol = Symbol(name)
-                            
+                
                 if isinstance(widget, MenuGui):
                     # Add menubar to container
                     widget.__magicclass_parent__ = self
@@ -131,8 +141,9 @@ class ClassGuiBase(BaseGui):
                                 _layout.setMenuBar(self._menubar)
                             else:
                                 raise RuntimeError(
-                                    "Cannot add both toolbar and menubar to a non-main window."
-                                    "Use maigcclass(widget_type='mainwindow') instead."
+                                    "Cannot add menubar after adding a toolbar in a non-main window. "
+                                    "Use maigcclass(widget_type='mainwindow') instead, or reorder "
+                                    "class definition."
                                     )
                     
                     widget.native.setParent(self._menubar, widget.native.windowFlags())
@@ -155,14 +166,14 @@ class ClassGuiBase(BaseGui):
                         self.native.addToolBar(widget.native)
                     else:
                         # self is not a main window object
-                        _layout: QBoxLayout = self.native.layout()
+                        _layout: QBoxLayout = self._widget._layout
                         if _layout.menuBar() is None:
                             _layout.setMenuBar(widget.native)
                         else:
-                            raise RuntimeError(
-                                "Cannot add two or more toolbars and/or menubars to a non-main"
-                                "window. Use maigcclass(widget_type='mainwindow') instead."
-                                )
+                            _layout.insertWidget(0, widget.native, alignment=Qt.AlignTop)
+                            widget.native.setContentsMargins(0, 0, 0, 0)
+                            n_insert += 1
+                            
                     _hist.append((name, type(attr), "ToolBarGui"))
                 
                 elif isinstance(widget, (Widget, Callable)):
@@ -207,7 +218,7 @@ class ClassGuiBase(BaseGui):
                 hist_str = "\n\t".join(map(
                     lambda x: f"{x[0]} {x[1]} -> {x[2]}",
                     _hist
-                    )) + f"\n\t\t{name} ({type(attr).__name__}) <--- Error"
+                    )) + f"\n\t\t{name} ({type(attr)}) <--- Error"
                 if not hist_str.startswith("\n\t"):
                     hist_str = "\n\t" + hist_str
                 if isinstance(e, MagicClassConstructionError):
@@ -337,6 +348,16 @@ def make_gui(container: type[ContainerWidget], no_margin: bool = True):
                 run_app()
             return None
         
+        
+        def reset_choices(self: cls, *_: Any):
+            """Reset child Categorical widgets"""
+            for widget in self:
+                if hasattr(widget, "reset_choices"):
+                    widget.reset_choices()
+            for widget in self.__magicclass_children__:
+                if hasattr(widget, "reset_choices"):
+                    widget.reset_choices()
+        
         def close(self: cls):
             current_self = self._search_parent_magicclass()
             
@@ -356,6 +377,7 @@ def make_gui(container: type[ContainerWidget], no_margin: bool = True):
         cls._fast_insert = _fast_insert
         cls.insert = insert
         cls.show = show
+        cls.reset_choices = reset_choices
         cls.close = close
         cls._container_widget = container
         cls._remove_child_margins = no_margin
